AppText class

Inheritance

Constructors

AppText({Key? key, TextStyle? googlefont, Color? color, required String text, double? size, double? letterspace, FontWeight? weight, String? family, TextAlign? textalign, int? maxline})

Properties

color ↔ Color?
getter/setter pair
family ↔ String?
getter/setter pair
googlefont ↔ TextStyle?
getter/setter pair
hashCode → int
The hash code for this object.
no setterinherited
key → Key?
Controls how one widget replaces another widget in the tree.
finalinherited
letterspace ↔ double?
getter/setter pair
maxline ↔ int?
getter/setter pair
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited
size ↔ double?
getter/setter pair
text ↔ String
getter/setter pair
textalign ↔ TextAlign?
getter/setter pair
weight ↔ FontWeight?
getter/setter pair

Methods

build(BuildContext context) → Widget
Describes the part of the user interface represented by this widget.
override
createElement() → StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() → List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) → String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String
Returns a one-line detailed description of the object.
inherited
toStringShort() → String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited